@@ -184,9 +184,9 @@ panel_context_menu_setup_remove_panel_item (GtkWidget *menu,
 	g_assert (PANEL_IS_TOPLEVEL (panel_widget->toplevel));
 
 	sensitive =
-		panel_toplevel_is_last_unattached (panel_widget->toplevel) ||
-		!panel_lockdown_get_locked_down () ||
-		!panel_profile_id_lists_are_writable ();
+		!panel_toplevel_is_last_unattached (panel_widget->toplevel) &&
+		!panel_lockdown_get_locked_down () &&
+		panel_profile_id_lists_are_writable ();
 
 	gtk_widget_set_sensitive (menuitem, sensitive);
 
@@ -295,7 +295,6 @@ panel_context_menu_create (PanelWidget *panel)
 	if (panel->master_widget) {
 		gpointer    *pointer;
 		AppletInfo  *info;
-		PanelWidget *parent_panel;
 
 		pointer = g_object_get_data (G_OBJECT (panel->master_widget),
 					     "applet_info");
@@ -304,7 +303,6 @@ panel_context_menu_create (PanelWidget *panel)
 		info = (AppletInfo *) pointer;
 
 		if (info->menu == NULL) {
-			parent_panel = PANEL_WIDGET (info->widget->parent);
 			info->menu = panel_applet_create_menu (info);
 		}
 
