@@ -309,16 +309,30 @@ panel_profile_get_queued_changes (GObject *object)
 	return g_object_get_qdata (object, queued_changes_quark);
 }
 
+static void
+panel_porfile_remove_commit_timeout (guint timeout)
+{
+	g_source_remove (timeout);
+}
+
 static void
 panel_profile_set_commit_timeout (PanelToplevel *toplevel,
 				  guint          timeout)
 {
+	GDestroyNotify destroy_notify;
+
 	if (!commit_timeout_quark)
 		commit_timeout_quark = g_quark_from_static_string ("panel-queued-timeout");
 
-	g_object_set_qdata (G_OBJECT (toplevel),
-			    commit_timeout_quark,
-			    GUINT_TO_POINTER (timeout));
+	if (timeout)
+		destroy_notify = (GDestroyNotify) panel_porfile_remove_commit_timeout;
+	else
+		destroy_notify = NULL;
+
+	g_object_set_qdata_full (G_OBJECT (toplevel),
+				 commit_timeout_quark,
+				 GUINT_TO_POINTER (timeout),
+				 destroy_notify);
 }
 
 static guint
@@ -1158,9 +1172,6 @@ panel_profile_background_change_notify (GConfClient   *client,
 	if (!strcmp (key, "type")) {
 		if (value->type == GCONF_VALUE_STRING) {
 			PanelBackgroundType  background_type;
-			const char          *str;
-
-			str = gconf_value_get_string (value);
 
 			if (panel_profile_map_background_type_string (
 						gconf_value_get_string (value),
@@ -1966,7 +1977,11 @@ panel_profile_load_added_ids (GConfClient            *client,
 	}
 
 	for (l = added_ids; l; l = l->next) {
-		load_handler (client, PANEL_CONFIG_DIR, type, l->data);
+		char *id;
+		id = (char *) l->data;
+
+		if (id && id[0])
+			load_handler (client, PANEL_CONFIG_DIR, type, id);
 
 		g_free (l->data);
 		l->data = NULL;
@@ -2144,7 +2159,11 @@ panel_profile_load_list (GConfClient           *client,
 					  TRUE);
 
 	for (l = list; l; l = l->next) {
-		load_handler (client, profile_dir, type, l->data);
+		char *id;
+		id = (char *) l->data;
+
+		if (id && id[0])
+			load_handler (client, profile_dir, type, id);
 
 		g_free (l->data);
 		l->data = NULL;
@@ -2161,25 +2180,22 @@ panel_profile_copy_defaults_for_screen (GConfClient       *client,
 	GSList     *default_ids, *l;
 	GSList     *new_ids = NULL;
 	const char *key;
-	const char *id_list, *type_str, *schemas_str;
+	const char *id_list, *type_str;
 
 	id_list = panel_gconf_key_type_to_id_list (type);
 
 	switch (type) {
 	case PANEL_GCONF_TOPLEVELS:
 		type_str    = "toplevels";
-		schemas_str = "toplevels";
 		break;
 	case PANEL_GCONF_OBJECTS:
 		type_str    = "objects";
-		schemas_str = "objects";
 		break;
 	case PANEL_GCONF_APPLETS:
 		type_str    = "applets";
-		schemas_str = "objects";
 		break;
 	default:
-		type_str = schemas_str = NULL;
+		type_str = NULL;
 		g_assert_not_reached ();
 		break;
 	}
